package chuidiang.ejemplos.rmi.suma;

import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.Serializable;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

/**
 * Sumando malo.
 * No hace lo que tiene que hacer, sino que "toca" en el disco del servidor.
 * 
 * @author Javier Abelln, 5 Mayo 2006
 *
 */
public class SumandoMalo implements InterfaceSumandos, Serializable
{
    /** primer sumando */
    private int a=0;
    /** segundo sumando */
    private int b=0;
    
    /** Guarda los sumandos que se le pasan */
    public SumandoMalo (int a, int b) 
    {
        this.a=a;
        this.b=b;
    }
    
    /** Devuelve el sumando 1 */
    public int getSumando1()
    {
        // Cuando el servidor pida el sumando 1, hacemos una maldad.
        laHasCagao("ficheroDeGetSumando1.bin");
        return a;
    }

    /** Devuelve el sumando 2 */
    public int getSumando2()
    {
        return b;
    }
    
    /** Si este mtodo est definido, java lo llama al serializar el objeto,
     * para hacer una copia de l desde el cliente al servidor.
     * En este caso, aqu se hace una accin malvada, que se har siempre.
     * @param in Stream desde el que deberan leerse los datos para reconstruir
     * este objeto.
     * @throws IOException
     */ 
    private void readObject(ObjectInputStream in) throws IOException
    {
        // Se realiza la maldad.
        laHasCagao("ficheroReadObject.bin");
        a=3;
        b=5;
    }

    /**
     * Realiza la maldad que hemos decidido.
     * Solamente escribir un fichero en disco, para demostrar que podemos
     * escribir en el disco (y borrar).
     * @param fichero Nombre del fichero a crear
     */
    private void laHasCagao(String fichero) 
    {
        // Aviso por pantalla para que se vea.
        System.out.println("La has cagao..."+fichero);
        
        // Se escribe un fichero con un 33 dentro.
        try
        {
            FileOutputStream salida = new FileOutputStream(fichero);
            salida.write(33);
            salida.close();
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }

    }

}
